@@ -1,5 +1,6 @@
 from paramiko.client import SSHClient, AutoAddPolicy
 from paramiko.pkey import PKey
+from paramiko import RSAKey
 from paramiko.sftp_attr import SFTPAttributes
 from typing import Union, List
 from salure_helpers.salureconnect import SalureConnect
@@ -24,7 +25,7 @@ class SFTP(SalureConnect):
         self.username = credentials['username']
         self.password = credentials['password']
         # untested
-        self.private_key = PKey().from_private_key(open(credentials['private_key_path'], mode='r'), password=credentials['private_key_password']) if credentials['private_key_path'] is not None else None
+        self.private_key = RSAKey.from_private_key(open(credentials['private_key_path'], mode='r'), password=credentials['private_key_password']) if credentials['private_key_path'] is not None else None
         policy = AutoAddPolicy()
         self.client = SSHClient()
         self.client.set_missing_host_key_policy(policy)
